@@ -47,6 +47,10 @@ format_parameters.rma <- function(model) {
 }
 
 
+#' @export
+format_parameters.mira <- format_parameters.rma
+
+
 #' @export
 format_parameters.parameters_model <- function(model) {
   if (!is.null(attributes(model)$pretty_names)) {
@@ -200,6 +204,16 @@ format_parameters.parameters_model <- function(model) {
     name <- .format_log(name = name, variable = variable, type = type)
   }
 
+  # exp-transformation
+  if (type == "exponentiation") {
+    name <- .format_log(name = name, variable = variable, type = type)
+  }
+
+  # log-transformation
+  if (type == "squareroot") {
+    name <- .format_log(name = name, variable = variable, type = type)
+  }
+
   # As Is
   if (type == "asis") {
     name <- variable
