@@ -1,5 +1,6 @@
+#' @inheritParams model_parameters.merMod
 #' @export
-model_parameters.wbm <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, exponentiate = FALSE, ...) {
+model_parameters.wbm <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, exponentiate = FALSE, details = FALSE, p_adjust = NULL, ...) {
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -8,10 +9,17 @@ model_parameters.wbm <- function(model, ci = .95, bootstrap = FALSE, iterations
     merge_by = c("Parameter", "Component"),
     standardize = NULL,
     exponentiate = exponentiate,
+    robust = FALSE,
+    p_adjust = p_adjust,
     ...
   )
 
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+
+  if (isTRUE(details)) {
+    attr(out, "details") <- .randomeffects_summary(model)
+  }
+
   out
 }
 
