@@ -1,4 +1,4 @@
-#' Model Parameters from Zero-Inflated Models
+#' Parameters from Zero-Inflated Models
 #'
 #' Parameters from zero-inflated models.
 #'
@@ -11,15 +11,15 @@
 #'
 #' @examples
 #' library(parameters)
-#' library(pscl)
-#'
-#' data("bioChemists")
-#' model <- zeroinfl(art ~ fem + mar + kid5 + ment | kid5 + phd, data = bioChemists)
-#' model_parameters(model)
+#' if (require("pscl")) {
+#'   data("bioChemists")
+#'   model <- zeroinfl(art ~ fem + mar + kid5 + ment | kid5 + phd, data = bioChemists)
+#'   model_parameters(model)
+#' }
 #' @return A data frame of indices related to the model's parameters.
 #' @inheritParams simulate_model
 #' @export
-model_parameters.zeroinfl <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, component = c("all", "conditional", "zi", "zero_inflated"), standardize = NULL, exponentiate = FALSE, robust = FALSE, ...) {
+model_parameters.zeroinfl <- function(model, ci = .95, bootstrap = FALSE, iterations = 1000, component = c("all", "conditional", "zi", "zero_inflated"), standardize = NULL, exponentiate = FALSE, robust = FALSE, p_adjust = NULL, ...) {
   component <- match.arg(component)
 
   # fix argument, if model has no zi-part
@@ -32,7 +32,7 @@ model_parameters.zeroinfl <- function(model, ci = .95, bootstrap = FALSE, iterat
   if (bootstrap) {
     parameters <- bootstrap_parameters(model, iterations = iterations, ci = ci, ...)
   } else {
-    parameters <- .extract_parameters_generic(model, ci = ci, component = component, standardize = standardize, robust = robust, ...)
+    parameters <- .extract_parameters_generic(model, ci = ci, component = component, standardize = standardize, robust = robust, p_adjust = p_adjust, ...)
   }
 
 
@@ -50,3 +50,6 @@ model_parameters.hurdle <- model_parameters.zeroinfl
 
 #' @export
 model_parameters.zerocount <- model_parameters.zeroinfl
+
+#' @export
+model_parameters.zcpglm <- model_parameters.zeroinfl
