@@ -39,6 +39,14 @@ BayesFactor::correlationBF(iris$Sepal.Length, iris$Sepal.Width) %>%
 BayesFactor::ttestBF(formula = mpg ~ vs, data = mtcars) %>% 
   parameters()
 
+## ---- warning=FALSE, message=FALSE--------------------------------------------
+aov(Sepal.Length ~ Species, data = iris) %>%
+  parameters(omega_squared = "partial", eta_squared = "partial", epsilon_squared = "partial")
+
+## ---- warning=FALSE, message=FALSE--------------------------------------------
+aov(mpg ~ am + Error(gear), data = mtcars) %>%
+  parameters()
+
 ## ---- warning=FALSE, message=FALSE--------------------------------------------
 glm(vs ~ poly(mpg, 2) + cyl, data = mtcars) %>% 
   parameters()
@@ -49,6 +57,39 @@ library(lme4)
 lmer(Sepal.Width ~ Petal.Length + (1|Species), data = iris) %>% 
   parameters()
 
+## ---- warning=FALSE, message=FALSE--------------------------------------------
+library(GLMMadaptive)
+library(glmmTMB)
+data("Salamanders")
+model <- mixed_model(
+  count ~ spp + mined,
+  random = ~1 | site,
+  zi_fixed = ~spp + mined,
+  family = zi.negative.binomial(), 
+  data = Salamanders
+)
+parameters(model)
+
+## ---- warning=FALSE, message=FALSE--------------------------------------------
+library(glmmTMB)
+sim1 <- function(nfac = 40, nt = 100, facsd = 0.1, tsd = 0.15, mu = 0, residsd = 1) {
+  dat <- expand.grid(fac = factor(letters[1:nfac]), t = 1:nt)
+  n <- nrow(dat)
+  dat$REfac <- rnorm(nfac, sd = facsd)[dat$fac]
+  dat$REt <- rnorm(nt, sd = tsd)[dat$t]
+  dat$x <- rnorm(n, mean = mu, sd = residsd) + dat$REfac + dat$REt
+  dat
+}
+set.seed(101)
+d1 <- sim1(mu = 100, residsd = 10)
+d2 <- sim1(mu = 200, residsd = 5)
+d1$sd <- "ten"
+d2$sd <- "five"
+dat <- rbind(d1, d2)
+model <- glmmTMB(x ~ sd + (1 | t), dispformula =  ~ sd, data = dat)
+
+parameters(model)
+
 ## ---- warning=FALSE, message=FALSE, eval = FALSE------------------------------
 #  library(rstanarm)
 #  
