@@ -6,6 +6,7 @@ knitr::opts_chunk$set(comment = "#>")
 
 if (!requireNamespace("dplyr", quietly = TRUE) ||
     !requireNamespace("performance", quietly = TRUE) ||
+    !requireNamespace("rstanarm", quietly = TRUE) ||
     !requireNamespace("lme4", quietly = TRUE)) {
   knitr::opts_chunk$set(eval = FALSE)
 } else {
@@ -16,7 +17,7 @@ if (!requireNamespace("dplyr", quietly = TRUE) ||
 set.seed(333)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-model <- lm(Sepal.Length ~ .*., data=iris)
+model <- lm(Sepal.Length ~ .*., data = iris)
 summary(model)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
@@ -34,8 +35,22 @@ lm(Sepal.Length ~ .*., data = iris) %>%
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
 library(lme4)
+data("qol_cancer")
 
-lmer(Sepal.Length ~ Sepal.Width * Petal.Length * Petal.Width + (1|Species), data = iris) %>%
+# multiple models are checked, however, initial models
+# already seems to be the best one...
+lmer(
+  QoL ~ time + phq4 + age + (1 + time | hospital / ID),
+  data = qol_cancer
+) %>% 
   select_parameters() %>%
   summary()
 
+## ----message=FALSE, warning=FALSE---------------------------------------------
+library(rstanarm)
+model <- stan_glm(
+  mpg ~ ., data = mtcars,
+  iter = 500, refresh = 0, verbose = FALSE
+)
+select_parameters(model, cross_validation = TRUE)
+
